====================
Significance Testing
====================

xeofs is dedicated to providing a user-friendly interface for model evaluations using bootstrapping. Currently, it supports bootstrapping for PCA/EOF analysis. 
For a practical example, see the :doc:`validation example <../auto_examples/4validation/index>`.